@@ -1,10 +1,16 @@
+use crate::markdown::ToMarkDown;
+use crate::schema::root_schema;
 use clap::Parser;
 use cocogitto::settings::Settings;
-use schemars::schema_for;
+use cog_schemars::schema_for;
 use std::fs;
+use std::io::{BufWriter, Write};
 use std::path::PathBuf;
 
-const _CONFIG_REFERENCE_HEADING: &str = r#"# Configuration reference
+mod markdown;
+mod schema;
+
+const CONFIG_REFERENCE_HEADING: &str = r#"# Configuration reference
 
 The config reference list all value that can be set in the `cog.toml` file at the root of a repository.
 
@@ -23,6 +29,10 @@ pub enum Cli {
         #[arg(short, long)]
         out: Option<PathBuf>,
     },
+    Reference {
+        #[arg(short, long)]
+        out: PathBuf,
+    },
 }
 fn main() -> anyhow::Result<()> {
     let cli = Cli::parse();
@@ -36,6 +46,15 @@ fn main() -> anyhow::Result<()> {
                 Some(out) => fs::write(out, schema)?,
             }
         }
+        Cli::Reference { out } => {
+            let mut root = root_schema()?;
+            let buffer = vec![];
+            let mut writer = BufWriter::new(buffer);
+            writer.write_all(CONFIG_REFERENCE_HEADING.as_bytes())?;
+            root.to_markdown(&mut writer)?;
+            let content = writer.into_inner()?;
+            fs::write(out, content)?;
+        }
     }
 
     Ok(())
