@@ -17,6 +17,23 @@ static FILTER_MERGE_COMMITS: Lazy<fn(&&git2::Commit) -> bool> = Lazy::new(|| {
     }
 });
 
+static FILTER_FIXUP_COMMITS: Lazy<fn(&&git2::Commit) -> bool> = Lazy::new(|| {
+    |commit| {
+        if SETTINGS.ignore_fixup_commits {
+            commit
+                .message()
+                .map(|msg| {
+                    !msg.starts_with("fixup!")
+                        || !msg.starts_with("squash!")
+                        || !msg.starts_with("amend!")
+                })
+                .unwrap_or(true)
+        } else {
+            true
+        }
+    }
+});
+
 pub(crate) trait Bump {
     fn manual_bump(&self, version: &str) -> Result<Self, semver::Error>
     where
@@ -146,6 +163,7 @@ impl Tag {
         let commits: Vec<&Git2Commit> = commits
             .iter_commits()
             .filter(&*FILTER_MERGE_COMMITS)
+            .filter(&*FILTER_FIXUP_COMMITS)
             .collect();
 
         let conventional_commits: Vec<Commit> = commits
@@ -180,6 +198,7 @@ impl Tag {
         let commits: Vec<&Git2Commit> = commits
             .iter_commits()
             .filter(&*FILTER_MERGE_COMMITS)
+            .filter(&*FILTER_FIXUP_COMMITS)
             .collect();
 
         let conventional_commits: Vec<Commit> = commits
@@ -213,6 +232,7 @@ impl Tag {
         let commits: Vec<&Git2Commit> = commits
             .iter_commits()
             .filter(&*FILTER_MERGE_COMMITS)
+            .filter(&*FILTER_FIXUP_COMMITS)
             .collect();
 
         let conventional_commits: Vec<Commit> = commits
@@ -282,7 +302,6 @@ mod test {
     use crate::git::tag::Tag;
     use crate::settings::{MonoRepoPackage, Settings};
     use crate::test_helpers::{git_init_no_gpg, git_tag};
-    use crate::CommitConfigOrNull;
 
     impl Commit {
         fn commit_fixture(commit_type: CommitType, is_breaking_change: bool) -> Self {
@@ -511,10 +530,7 @@ mod test {
         // Arrange
         git_init_no_gpg()?;
         let mut commit_types = HashMap::new();
-        commit_types.insert(
-            "ex".to_string(),
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Ex").with_minor_bump()),
-        );
+        commit_types.insert("ex".to_string(), CommitConfig::new("Ex").with_minor_bump());
         let settings = Settings {
             commit_types,
             ..Default::default()
@@ -541,10 +557,7 @@ mod test {
         // Arrange
         git_init_no_gpg()?;
         let mut commit_types = HashMap::new();
-        commit_types.insert(
-            "ex".to_string(),
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Ex").with_patch_bump()),
-        );
+        commit_types.insert("ex".to_string(), CommitConfig::new("Ex").with_patch_bump());
         let settings = Settings {
             commit_types,
             ..Default::default()
@@ -573,7 +586,7 @@ mod test {
         let mut commit_types = HashMap::new();
         commit_types.insert(
             "perf".to_string(),
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Perf").with_minor_bump()),
+            CommitConfig::new("Perf").with_minor_bump(),
         );
         let settings = Settings {
             commit_types,
