@@ -62,6 +62,15 @@ impl TryFrom<CommitIter<'_>> for Release<'_> {
                             true
                         }
                     })
+                    .filter(|(_commit, commit)| {
+                        if SETTINGS.ignore_fixup_commits {
+                            !commit.message().unwrap().starts_with("fixup!")
+                                && !commit.message().unwrap().starts_with("squash!")
+                                && !commit.message().unwrap().starts_with("amend!")
+                        } else {
+                            true
+                        }
+                    })
                     .filter_map(|(_, commit)| match Commit::from_git_commit(commit) {
                         Ok(commit) => {
                             if !commit.should_omit() {
