@@ -2,7 +2,7 @@ use std::cmp::Ordering;
 use std::fmt::{self, Formatter};
 
 pub use crate::conventional::error::ConventionalCommitError;
-use crate::SETTINGS;
+use crate::{COMMITS_METADATA, SETTINGS};
 use chrono::{DateTime, NaiveDateTime, Utc};
 use colored::*;
 use conventional_commit_parser::commit::ConventionalCommit;
@@ -17,43 +17,75 @@ pub struct Commit {
     pub author: String,
     pub date: NaiveDateTime,
 }
-
+/// # CommitConfig
 /// Configurations to create new conventional commit types or override behaviors of the existing ones.
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Clone, Eq, PartialEq)]
 pub struct CommitConfig {
     /// Define the title used in generated changelog for this commit type.
-    pub changelog_title: String,
+    pub changelog_title: Option<String>,
     /// Do not display this commit type in changelogs.
     #[serde(default)]
-    pub omit_from_changelog: bool,
+    pub omit_from_changelog: Option<bool>,
     /// Allow for this commit type to bump the minor version.
     #[serde(default)]
-    pub bump_minor: bool,
+    pub bump_minor: Option<bool>,
     /// Allow for this commit type to bump the patch version.
     #[serde(default)]
-    pub bump_patch: bool,
+    pub bump_patch: Option<bool>,
 }
 
 impl CommitConfig {
     pub(crate) fn new(changelog_title: &str) -> Self {
         CommitConfig {
-            changelog_title: changelog_title.to_string(),
-            omit_from_changelog: false,
-            bump_minor: false,
-            bump_patch: false,
+            changelog_title: Some(changelog_title.to_string()),
+            omit_from_changelog: Some(false),
+            bump_minor: Some(false),
+            bump_patch: Some(false),
+        }
+    }
+
+    pub(crate) fn merge(self, other: CommitConfig) -> CommitConfig {
+        if other.none() {
+            return other;
+        }
+
+        CommitConfig {
+            changelog_title: other.changelog_title.or(self.changelog_title),
+            omit_from_changelog: other.omit_from_changelog.or(self.omit_from_changelog),
+            bump_minor: other.bump_minor.or(self.bump_minor),
+            bump_patch: other.bump_patch.or(self.bump_patch),
         }
     }
 
     pub(crate) fn with_minor_bump(mut self) -> Self {
-        self.bump_minor = true;
+        self.bump_minor = Some(true);
         self
     }
 
     pub(crate) fn with_patch_bump(mut self) -> Self {
-        self.bump_patch = true;
+        self.bump_patch = Some(true);
         self
     }
+
+    pub(crate) fn omit_from_changelog(&self) -> bool {
+        self.omit_from_changelog.unwrap_or_default()
+    }
+
+    pub(crate) fn bump_minor(&self) -> bool {
+        self.bump_minor.unwrap_or_default()
+    }
+
+    pub(crate) fn bump_patch(&self) -> bool {
+        self.bump_patch.unwrap_or_default()
+    }
+
+    pub(crate) fn none(&self) -> bool {
+        self.bump_patch.is_none()
+            && self.omit_from_changelog.is_none()
+            && self.bump_minor.is_none()
+            && self.changelog_title.is_none()
+    }
 }
 
 impl Commit {
@@ -82,10 +114,20 @@ impl Commit {
                     date,
                 };
 
-                match &SETTINGS
-                    .commit_types()
-                    .get(&commit.conventional.commit_type)
+                if let (Some(scopes), Some(scope)) =
+                    (&SETTINGS.commit_scopes(), &commit.conventional.scope)
                 {
+                    if !scopes.contains(scope) {
+                        return Err(Box::new(ConventionalCommitError::CommitScopeNotDefined {
+                            oid: commit.oid.to_string(),
+                            summary: format_summary(&commit.conventional),
+                            scope: scope.to_string(),
+                            author: commit.author,
+                        }));
+                    }
+                }
+
+                match &COMMITS_METADATA.get(&commit.conventional.commit_type) {
                     Some(_) => Ok(commit),
                     None => Err(Box::new(ConventionalCommitError::CommitTypeNotAllowed {
                         oid: commit.oid.to_string(),
@@ -117,10 +159,9 @@ impl Commit {
     }
 
     pub(crate) fn should_omit(&self) -> bool {
-        SETTINGS
-            .commit_types()
+        COMMITS_METADATA
             .get(&self.conventional.commit_type)
-            .map_or(false, |config| config.omit_from_changelog)
+            .is_some_and(|config| config.omit_from_changelog())
     }
 
     pub(crate) fn is_major_bump(&self) -> bool {
@@ -128,21 +169,19 @@ impl Commit {
     }
 
     pub(crate) fn is_minor_bump(&self) -> bool {
-        let commit_settings = SETTINGS.commit_types();
-        let Some(commit_config) = commit_settings.get(&self.conventional.commit_type) else {
+        let Some(commit_config) = COMMITS_METADATA.get(&self.conventional.commit_type) else {
             return false;
         };
 
-        commit_config.bump_minor
+        commit_config.bump_minor()
     }
 
     pub(crate) fn is_patch_bump(&self) -> bool {
-        let commit_settings = SETTINGS.commit_types();
-        let Some(commit_config) = commit_settings.get(&self.conventional.commit_type) else {
+        let Some(commit_config) = COMMITS_METADATA.get(&self.conventional.commit_type) else {
             return false;
         };
 
-        commit_config.bump_patch
+        commit_config.bump_patch()
     }
 
     pub fn get_log(&self) -> String {
@@ -249,6 +288,7 @@ pub fn verify(
     author: Option<String>,
     message: &str,
     ignore_merge_commit: bool,
+    ignore_fixup_commit: bool,
 ) -> Result<(), Box<ConventionalCommitError>> {
     // Strip away comments from git message before parsing
     let msg: String = message
@@ -264,10 +304,25 @@ pub fn verify(
         return Ok(());
     }
 
+    if msg.starts_with("fixup!") && ignore_fixup_commit {
+        info!("{}", "fixup! commit was ignored".yellow());
+        return Ok(());
+    }
+
+    if msg.starts_with("amend!") && ignore_fixup_commit {
+        info!("{}", "amend! commit was ignored".yellow());
+        return Ok(());
+    }
+
+    if msg.starts_with("squash!") && ignore_fixup_commit {
+        info!("{}", "squash! commit was ignored".yellow());
+        return Ok(());
+    }
+
     let commit = conventional_commit_parser::parse(msg);
 
     match commit {
-        Ok(commit) => match &SETTINGS.commit_types().get(&commit.commit_type) {
+        Ok(commit) => match &COMMITS_METADATA.get(&commit.commit_type) {
             Some(_) => {
                 info!(
                     "{}",
@@ -369,7 +424,7 @@ mod test {
             },
         ]);
 
-        assert_that!(commit.to_string()).is_equal_to(&message.to_string())
+        assert_that!(commit.to_string()).is_equal_to(message.to_string())
     }
 
     #[test]
@@ -378,7 +433,7 @@ mod test {
         let message = "feat(database): add postgresql driver";
 
         // Act
-        let result = verify(Some("toml".into()), message, false);
+        let result = verify(Some("toml".into()), message, false, false);
 
         // Assert
         assert_that!(result).is_ok();
@@ -396,7 +451,7 @@ mod test {
         );
 
         // Act
-        let result = verify(Some("toml".into()), message, false);
+        let result = verify(Some("toml".into()), message, false, false);
 
         // Assert
         assert_that!(result).is_ok();
@@ -408,7 +463,7 @@ mod test {
         let message = "feat add postgresql driver";
 
         // Act
-        let result = verify(Some("toml".into()), message, false);
+        let result = verify(Some("toml".into()), message, false, false);
 
         // Assert
         assert_that!(result).is_err();
@@ -420,7 +475,7 @@ mod test {
         let message = "post: add postgresql driver";
 
         // Act
-        let result = verify(Some("toml".into()), message, false);
+        let result = verify(Some("toml".into()), message, false, false);
 
         // Assert
         assert_that!(result).is_err();
@@ -441,7 +496,7 @@ mod test {
             "
         );
 
-        let outcome = verify(None, message, false);
+        let outcome = verify(None, message, false, false);
 
         assert_that!(outcome).is_ok();
         Ok(())
@@ -504,25 +559,25 @@ mod test {
 
         // Assert
         assert!(
-            !&config.omit_from_changelog,
+            !&config.omit_from_changelog(),
             "expected CommitConfig::omit_from_changelog to be falsy unless explicitly set"
         );
 
         // Act
-        config.omit_from_changelog = true;
+        config.omit_from_changelog = Some(true);
 
         // Assert
         assert!(
-            &config.omit_from_changelog,
+            &config.omit_from_changelog(),
             "CommitConfig::omit_from_changelog should be truthy after calling CommitConfig::omit"
         );
 
         // Act
-        config.omit_from_changelog = false;
+        config.omit_from_changelog = Some(false);
 
         // Assert
         assert!(
-            !&config.omit_from_changelog,
+            !&config.omit_from_changelog(),
             "CommitConfig::omit_from_changelog should be falsy after calling CommitConfig::include"
         );
     }
