@@ -5,7 +5,7 @@ use std::path::PathBuf;
 
 use crate::conventional::commit::CommitConfig;
 use crate::git::repository::Repository;
-use crate::{CommitConfigOrNull, CommitsMetadata, CONFIG_PATH, SETTINGS};
+use crate::{CONFIG_PATH, SETTINGS};
 
 use crate::conventional::changelog::error::ChangelogError;
 use crate::conventional::changelog::template::{RemoteContext, Template};
@@ -20,15 +20,38 @@ pub(crate) type AuthorSettings = Vec<AuthorSetting>;
 
 mod error;
 
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
 #[derive(Copy, Clone)]
 pub enum HookType {
     PreBump,
     PostBump,
 }
 
-/// # Cocogitto config
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// # Settings
+/// Configuration structure for the Cocogitto tool.
+///
+/// This struct defines the main configuration options for Cocogitto, including settings
+/// for version generation, changelog handling, commit conventions, hooks, and monorepo support.
+///
+///  **Example :**
+/// ```toml
+/// # Basic settings
+/// from_latest_tag = true
+/// ignore_merge_commits = true
+///
+/// # Changelog settings
+/// [changelog]
+/// path = "CHANGELOG.md"
+/// template = "remote"
+///
+/// # Git hooks
+/// [git_hooks.pre-commit]
+/// script = "./scripts/pre-commit.sh"
+///
+/// # Monorepo configuration
+/// [packages.my-package]
+/// path = "packages/my-package"
+/// ```
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Eq, PartialEq)]
 #[serde(deny_unknown_fields, default)]
 pub struct Settings {
@@ -36,6 +59,8 @@ pub struct Settings {
     pub from_latest_tag: bool,
     /// A list of glob patterns to allow bumping only on matching branches.
     pub ignore_merge_commits: bool,
+    /// Silently ignore fixup commits
+    pub ignore_fixup_commits: bool,
     /// Whether to generate a changelog or not during bump.
     pub disable_changelog: bool,
     /// Whether to create a bump commit or not.
@@ -52,20 +77,33 @@ pub struct Settings {
     /// as a tag prefix, cocogitto will generate versions starting with `v` and
     /// commands like `cog changelog` will pick only those versions.
     pub tag_prefix: Option<String>,
-    /// A "skip-ci" string to add to the commits when using the `bump` or `commit commands.
+    /// A "skip-ci" string to add to the commits when using the `bump` or `commit` commands.
     /// Default value is `[skip ci].
     pub skip_ci: String,
-    /// Allows to perform bump even if there are untracked or uncommited changes.
+    /// Allows to perform bump even if there are untracked or uncommitted changes.
     pub skip_untracked: bool,
+    /// Hooks that will be executed before a bump command in root dir.
     pub pre_bump_hooks: Vec<String>,
+    /// Hooks that will be executed after a bump command in root dir.
     pub post_bump_hooks: Vec<String>,
+    /// Hooks that will be executed before a bump command in package dir.
     pub pre_package_bump_hooks: Vec<String>,
+    /// Hooks that will be executed after a bump command in package dir.
     pub post_package_bump_hooks: Vec<String>,
+    /// Git hooks configuration.
     pub git_hooks: HashMap<GitHookType, GitHook>,
-    pub commit_types: HashMap<String, CommitConfigOrNull>,
+    /// Custom commit types configuration.
+    // Note: the custom serde deserializer is needed to be able to serialize from an empty object `{}`
+    // to disable default commit. This translates to `Option<CommitConfig>` in the schemar doc generator.
+    pub commit_types: HashMap<String, CommitConfig>,
+    /// Changelog configuration.
     pub changelog: Changelog,
+    /// Custom bump profiles configurations.
     pub bump_profiles: HashMap<String, BumpProfile>,
+    /// Monorepo packages configuration.
     pub packages: HashMap<String, MonoRepoPackage>,
+    /// List of valid commit scopes.
+    pub scopes: Option<Vec<String>>,
 }
 
 impl Default for Settings {
@@ -73,6 +111,7 @@ impl Default for Settings {
         Self {
             from_latest_tag: false,
             ignore_merge_commits: false,
+            ignore_fixup_commits: true,
             disable_changelog: false,
             disable_bump_commit: false,
             generate_mono_repository_global_tag: true,
@@ -91,11 +130,24 @@ impl Default for Settings {
             changelog: Default::default(),
             bump_profiles: Default::default(),
             packages: Default::default(),
+            scopes: Default::default(),
         }
     }
 }
 
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// # GitHookType
+/// Represents the different types of Git hooks that can be configured.
+///
+/// This enum defines all the standard Git hook types that can be used
+/// in the configuration. Each variant corresponds to a specific Git hook
+/// that gets triggered at different points in Git's execution.
+///
+///  **Example :**
+/// ```toml
+/// [git_hooks.pre-commit]
+/// script = "./scripts/pre-commit.sh"
+/// ```
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Eq, PartialEq, Hash, Copy, Clone)]
 #[serde(deny_unknown_fields, rename_all = "kebab-case", into = "&str")]
 pub enum GitHookType {
@@ -186,20 +238,41 @@ impl fmt::Display for GitHookType {
     }
 }
 
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// # GitHook
+/// A GitHook can be defined either as a script string that will be executed directly,
+/// or as a path to a script file that will be executed
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Eq, PartialEq)]
 #[serde(deny_unknown_fields, untagged)]
 pub enum GitHook {
+    /// Direct script string that will be executed
     Script { script: String },
+    /// Path to a script file that will be executed
     File { path: PathBuf },
 }
 
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// # MonoRepoPackage
+/// Configuration for a package in a monorepo setup.
+///
+/// This struct defines how a single package within a monorepo should be handled,
+/// including its location, included/excluded files, changelog settings, and bump behavior.
+///
+///  **Example :**
+/// ```toml
+/// [packages.my-package]
+/// path = "packages/my-package"
+/// include = ["packages/my-package/**"]
+/// ignore = ["**/test/**"]
+/// changelog_path = "CHANGELOG.md"
+/// public_api = true
+/// bump_order = 1
+/// ```
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Eq, PartialEq)]
 #[serde(deny_unknown_fields, default)]
 pub struct MonoRepoPackage {
     /// The package path, relative to the repository root dir.
-    /// Used to scan commits and set hook commands current directory
+    /// Used to scan commits and set hook commands current directory.
     pub path: PathBuf,
     /// List of globs for additional paths to include, relative to
     /// the repository root dir.
@@ -207,16 +280,19 @@ pub struct MonoRepoPackage {
     /// List of globs for paths to ignore, relative to
     /// the repository root dir.
     pub ignore: Vec<String>,
-    /// Where to write the changelog
+    /// Where to write the changelog.
     pub changelog_path: Option<String>,
     /// Bumping package marked as public api will increment
-    /// the global monorepo version when using `cog bump --auto`
+    /// the global monorepo version when using `cog bump --auto`.
     pub public_api: bool,
-    /// Overrides `pre_package_bump_hooks`
+    /// Ordering of packages in the changelog, this affect in which order
+    /// packages will be bumped.
+    pub bump_order: Option<usize>,
+    /// Overrides `pre_package_bump_hooks`.
     pub pre_bump_hooks: Option<Vec<String>>,
-    /// Overrides `post_package_bump_hooks`
+    /// Overrides `post_package_bump_hooks`.
     pub post_bump_hooks: Option<Vec<String>>,
-    /// Custom profile to override `pre_bump_hooks`, `post_bump_hooks`
+    /// Custom profile to override `pre_bump_hooks`, `post_bump_hooks`.
     pub bump_profiles: HashMap<String, BumpProfile>,
 }
 
@@ -231,6 +307,7 @@ impl Default for &MonoRepoPackage {
             post_bump_hooks: None,
             bump_profiles: Default::default(),
             public_api: true,
+            bump_order: None,
         });
 
         Box::leak(package)
@@ -248,6 +325,7 @@ impl Default for MonoRepoPackage {
             post_bump_hooks: None,
             bump_profiles: Default::default(),
             public_api: true,
+            bump_order: None,
         }
     }
 }
@@ -262,16 +340,37 @@ impl MonoRepoPackage {
 }
 
 /// # Changelog
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// Configuration for changelog generation.
+///
+/// This struct defines how the changelog should be generated,
+/// including templates, remote repository information, and author settings.
+///
+///  **Example :**
+/// ```toml
+/// [changelog]
+/// template = "remote"
+/// path = "CHANGELOG.md"
+/// remote = "github.com"
+/// owner = "cocogitto"
+/// repository = "cocogitto"
+/// ```
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Clone, Eq, PartialEq)]
 #[serde(deny_unknown_fields, default)]
 pub struct Changelog {
+    /// Template to use for changelog generation. Can be "remote", "full_hash" or a custom template path
     pub template: Option<String>,
+    /// Template to use for package changelogs in monorepos
     pub package_template: Option<String>,
+    /// Remote Git repository URL (e.g. "github.com")
     pub remote: Option<String>,
+    /// Path where changelog file should be written
     pub path: PathBuf,
+    /// Repository owner/organization name
     pub owner: Option<String>,
+    /// Repository name
     pub repository: Option<String>,
+    /// Author mappings for changelog generation
     pub authors: AuthorSettings,
 }
 
@@ -289,11 +388,25 @@ impl Default for Changelog {
     }
 }
 
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// # AuthorSetting
+/// Configuration for mapping Git signatures to usernames.
+///
+/// This struct defines the mapping between a Git commit signature (email address)
+/// and the corresponding username to use in changelog generation.
+///
+///  **Example :**
+/// ```toml
+/// [[changelog.authors]]
+/// signature = "user@example.com"
+/// username = "githubuser"
+/// ```
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Clone, Eq, PartialEq)]
 #[serde(deny_unknown_fields)]
 pub struct AuthorSetting {
+    /// The Git commit signature (typically an email address)
     pub signature: String,
+    /// The username to display in changelogs
     pub username: String,
 }
 
@@ -310,13 +423,26 @@ pub fn changelog_path() -> &'static PathBuf {
     &SETTINGS.changelog.path
 }
 
-/// # Bump profile
-#[cfg_attr(feature = "docgen", derive(schemars::JsonSchema))]
+/// # BumpProfile
+/// A custom profile for configuring hooks that run before and after version bumps.
+///
+/// Bump profiles allow defining different sets of hooks that can be selected
+/// when running bump commands.
+///
+///  **Example :**
+/// ```toml
+/// [bump_profiles.production]
+/// pre_bump_hooks = ["./scripts/pre-release.sh"]
+/// post_bump_hooks = ["./scripts/post-release.sh"]
+/// ```
+#[cfg_attr(feature = "docgen", derive(cog_schemars::JsonSchema))]
 #[derive(Debug, Deserialize, Serialize, Default, Eq, PartialEq)]
 #[serde(deny_unknown_fields)]
 pub struct BumpProfile {
+    /// List of hooks to run before bumping the version
     #[serde(default)]
     pub pre_bump_hooks: Vec<String>,
+    /// List of hooks to run after bumping the version
     #[serde(default)]
     pub post_bump_hooks: Vec<String>,
 }
@@ -329,73 +455,64 @@ impl Settings {
         repository.try_into()
     }
 
-    pub fn commit_types(&self) -> HashMap<CommitType, CommitConfig> {
+    pub fn load_commit_types(&self) -> HashMap<CommitType, CommitConfig> {
         let commit_settings = self.commit_types.clone();
         let mut custom_types = HashMap::new();
 
         commit_settings.iter().for_each(|(key, value)| {
             let _ = custom_types.insert(CommitType::from(key.as_str()), value.clone());
         });
-        let mut default_types = Settings::default_commit_config();
+
+        let mut default_types: HashMap<CommitType, CommitConfig> =
+            Settings::default_commit_config()
+                .into_iter()
+                .map(|(key, config)| {
+                    if let Some(custom_config) = custom_types.remove(&key) {
+                        let config = config.merge(custom_config);
+                        (key, config)
+                    } else {
+                        (key, config)
+                    }
+                })
+                .collect();
 
         default_types.extend(custom_types);
-
         default_types
             .into_iter()
-            .filter_map(|(key, value)| match value {
-                CommitConfigOrNull::CommitConfig(config) => Some((key, config)),
-                CommitConfigOrNull::None {} => None,
-            })
+            .filter(|(_, config)| !config.none())
             .collect()
     }
 
-    fn default_commit_config() -> CommitsMetadata {
+    pub fn commit_scopes(&self) -> Option<Vec<String>> {
+        self.scopes.clone()
+    }
+
+    fn default_commit_config() -> HashMap<CommitType, CommitConfig> {
         let mut default_types = HashMap::new();
         default_types.insert(
             CommitType::Feature,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Features").with_minor_bump()),
+            CommitConfig::new("Features").with_minor_bump(),
         );
         default_types.insert(
             CommitType::BugFix,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Bug Fixes").with_patch_bump()),
+            CommitConfig::new("Bug Fixes").with_patch_bump(),
         );
 
-        default_types.insert(
-            CommitType::Chore,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Miscellaneous Chores")),
-        );
-        default_types.insert(
-            CommitType::Revert,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Revert")),
-        );
+        default_types.insert(CommitType::Chore, CommitConfig::new("Miscellaneous Chores"));
+        default_types.insert(CommitType::Revert, CommitConfig::new("Revert"));
         default_types.insert(
             CommitType::Performances,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Performance Improvements")),
+            CommitConfig::new("Performance Improvements"),
         );
         default_types.insert(
             CommitType::Documentation,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Documentation")),
-        );
-        default_types.insert(
-            CommitType::Style,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Style")),
-        );
-        default_types.insert(
-            CommitType::Refactor,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Refactoring")),
-        );
-        default_types.insert(
-            CommitType::Test,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Tests")),
-        );
-        default_types.insert(
-            CommitType::Build,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Build system")),
-        );
-        default_types.insert(
-            CommitType::Ci,
-            CommitConfigOrNull::CommitConfig(CommitConfig::new("Continuous Integration")),
+            CommitConfig::new("Documentation"),
         );
+        default_types.insert(CommitType::Style, CommitConfig::new("Style"));
+        default_types.insert(CommitType::Refactor, CommitConfig::new("Refactoring"));
+        default_types.insert(CommitType::Test, CommitConfig::new("Tests"));
+        default_types.insert(CommitType::Build, CommitConfig::new("Build system"));
+        default_types.insert(CommitType::Ci, CommitConfig::new("Continuous Integration"));
         default_types
     }
 
@@ -552,6 +669,7 @@ mod test {
 [commit_types]
 feat = {}
 "#;
+
         fs::write("cog.toml", settings)?;
         assert_that!(COMMITS_METADATA.keys()).does_not_contain(&CommitType::Feature);
         assert_that!(COMMITS_METADATA.keys()).contains(&CommitType::BugFix);
