@@ -4,6 +4,7 @@ use std::path::PathBuf;
 
 use anyhow::Result;
 use cmd_lib::run_cmd;
+use cmd_lib::run_fun;
 use sealed_test::prelude::*;
 use speculoos::prelude::*;
 
@@ -273,6 +274,78 @@ fn consecutive_package_bump_ok() -> Result<()> {
     Ok(())
 }
 
+#[sealed_test]
+fn ordered_package_bump() -> Result<()> {
+    // Arrange
+    let mut settings = Settings {
+        ignore_merge_commits: true,
+        ..Default::default()
+    };
+
+    let jenkins = || MonoRepoPackage {
+        path: PathBuf::from("jenkins"),
+        public_api: false,
+        changelog_path: Some("jenkins/CHANGELOG.md".to_owned()),
+        bump_order: Some(2),
+        ..Default::default()
+    };
+
+    settings.packages.insert("jenkins".to_owned(), jenkins());
+
+    let thumbor = || MonoRepoPackage {
+        path: PathBuf::from("thumbor"),
+        public_api: false,
+        changelog_path: Some("thumbor/CHANGELOG.md".to_owned()),
+        bump_order: Some(1),
+        ..Default::default()
+    };
+
+    settings.packages.insert("thumbor".to_owned(), thumbor());
+
+    let settings = toml::to_string(&settings)?;
+
+    git_init()?;
+    run_cmd!(
+        echo Hello > README.md;
+        git add .;
+        git commit -m "chore: first commit";
+        mkdir jenkins;
+        echo "some jenkins stuff" > jenkins/file;
+        git add .;
+        git commit -m "feat(jenkins): add jenkins stuffs";
+        mkdir thumbor;
+        echo "some thumbor stuff" > thumbor/file;
+        git add .;
+        git commit -m "feat(thumbor): add thumbor stuffs";
+        echo $settings > cog.toml;
+        git add .;
+        git commit -m "chore: add cog.toml";
+    )?;
+
+    let mut cocogitto = CocoGitto::get()?;
+
+    // Act
+    cocogitto.create_monorepo_version(BumpOptions {
+        increment: IncrementCommand::Auto,
+        pre_release: None,
+        build: None,
+        hooks_config: None,
+        annotated: None,
+        dry_run: false,
+        skip_ci: false,
+        skip_ci_override: None,
+        skip_untracked: false,
+        disable_bump_commit: false,
+    })?;
+
+    // Assert
+    let tags_sorted_by_date = run_fun!(git tag --sort=-taggerdate)?;
+    let tags_sorted_by_date: Vec<&str> = tags_sorted_by_date.lines().collect();
+    assert_that!(tags_sorted_by_date).is_equal_to(vec!["0.0.0", "jenkins-0.1.0", "thumbor-0.1.0"]);
+
+    Ok(())
+}
+
 #[sealed_test]
 fn should_fallback_to_0_0_0_when_there_is_no_tag() -> Result<()> {
     // Arrange
@@ -699,7 +772,7 @@ fn bump_no_error_should_be_thrown_on_only_chore_docs_commit() -> Result<()> {
 }
 
 #[sealed_test]
-fn error_on_no_conventionnal_commits_found_for_monorepo() -> Result<()> {
+fn error_on_no_conventional_commits_found_for_monorepo() -> Result<()> {
     let settings = Settings {
         ..Default::default()
     };
@@ -746,7 +819,7 @@ fn error_on_no_conventionnal_commits_found_for_monorepo() -> Result<()> {
 }
 
 #[sealed_test]
-fn error_on_no_conventionnal_commits_found_for_package() -> Result<()> {
+fn error_on_no_conventional_commits_found_for_package() -> Result<()> {
     // Arrange
     let mut packages = HashMap::new();
     let jenkins = || MonoRepoPackage {
@@ -811,7 +884,7 @@ fn error_on_no_conventionnal_commits_found_for_package() -> Result<()> {
 }
 
 #[sealed_test]
-fn bump_with_unconventionnal_and_conventional_commits_found_for_packages() -> Result<()> {
+fn bump_with_unconventional_and_conventional_commits_found_for_packages() -> Result<()> {
     // Arrange
     let mut packages = HashMap::new();
     let jenkins = || MonoRepoPackage {
